aboutsummaryrefslogtreecommitdiffstats
path: root/shared/src
diff options
context:
space:
mode:
Diffstat (limited to 'shared/src')
-rw-r--r--shared/src/main/java/com/vaadin/shared/ui/grid/GridState.java21
1 files changed, 18 insertions, 3 deletions
diff --git a/shared/src/main/java/com/vaadin/shared/ui/grid/GridState.java b/shared/src/main/java/com/vaadin/shared/ui/grid/GridState.java
index 77744a9bb0..f2ebd903b2 100644
--- a/shared/src/main/java/com/vaadin/shared/ui/grid/GridState.java
+++ b/shared/src/main/java/com/vaadin/shared/ui/grid/GridState.java
@@ -147,11 +147,26 @@ public class GridState extends AbstractSingleSelectState {
public boolean columnReorderingAllowed;
/**
* Explicit row height in pixels for grid rows, or -1 to calculate
* automatically based on the theme.
*
- * @since 8.1
+ * @since 8.1.2
*/
- public double rowHeight = -1;
+ public double bodyRowHeight = -1;
+ /**
+ * Explicit body row height in pixels for grid rows, or -1 to calculate
+ * automatically based on the theme.
+ *
+ * @since 8.1.2
+ */
+ public double headerRowHeight = -1;
+
+ /**
+ * Explicit body row height in pixels for grid rows, or -1 to calculate
+ * automatically based on the theme.
+ *
+ * @since 8.1.2
+ */
+ public double footerRowHeight = -1;
}
@@ -147,11 +147,26 @@ public class GridState extends AbstractSingleSelectState {
public boolean columnReorderingAllowed;
/**
- * Explicit row height in pixels for grid rows, or -1 to calculate
+ * Explicit body row height in pixels for grid rows, or -1 to calculate
* automatically based on the theme.
*